==> qtjambi-sensors-6.3.0-sources.jar: io/qt/sensors/QOrientationSensor.java <==
package io.qt.sensors;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qorientationsensor.html">QOrientationSensor</a></p>
 */
public class QOrientationSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QOrientationSensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QOrientationSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QOrientationSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qorientationsensor.html#QOrientationSensor">QOrientationSensor::QOrientationSensor(QObject*)</a></p>
     */
    public QOrientationSensor(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QOrientationSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::reading()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.sensors.QOrientationReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.sensors.QOrientationReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QOrientationSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QOrientationSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QOrientationSensor instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.5.2-sources.jar: io/qt/sensors/QOrientationSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qorientationsensor.html">QOrientationSensor</a></code></p>
 */
public class QOrientationSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QOrientationSensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QOrientationSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QOrientationSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qorientationsensor.html#QOrientationSensor">QOrientationSensor::<wbr>QOrientationSensor(QObject*)</a></code></p>
     */
    public QOrientationSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QOrientationSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QOrientationReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QOrientationReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QOrientationSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QOrientationSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QOrientationSensor instance, QDeclarativeConstructor constructor);
    
}
